==> dcl_5.4.6.orig.tar.gz: dcl-5.4.6/demo/rakuraku/kihon/kihonb.f <==
*-----------------------------------------------------------------------
*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
*-----------------------------------------------------------------------
      PROGRAM KIHONB

      PARAMETER( NMAX=9 )
      REAL Y(NMAX)
      CHARACTER GREEK1*10, GREEK2*10, SYMBOL*10, CSGI*1

      WRITE(*,*) ' WORKSTATION ID (I)  ? ;'
      CALL SGPWSN
      READ (*,*) IWS

      CALL SGOPN(IWS)
      CALL SGFRM

      X1 = 0.1
      X2 = 0.9
      XC = 0.5

*-- 罫線 ----
      DO 10 N=1,NMAX
        Y(N) = 0.1*(10-N)
        CALL SGLNV( X1, Y(N), X2, Y(N) )
  10  CONTINUE

      CALL SGLNV( XC, 0.05, XC, 0.95 )

*-- デフォルト ----
      CALL SGTXV( XC, Y(1), 'SGTXV|SUP"RST_SUB"' )

*-- 添字 ----
      CALL SGLSET( 'LCNTL', .TRUE. )
      CALL SGTXV( XC, Y(2), 'SGTXV|SUP"RST_SUB"' )

      CALL SGRSET( 'SMALL', 0.5 )
      CALL SGRSET( 'SHIFT', 0.5 )
      CALL SGTXV( XC, Y(3), 'SGTXV|SUP"RST_SUB"' )

*-- フォント ----
      CALL SGTXV( XC, Y(4), 'ABCDEFG abcdefg' )

      CALL SGISET( 'IFONT', 2 )
      CALL SGTXV( XC, Y(5), 'ABCDEFG abcdefg' )

      CALL SGSTXI( 3 )
      CALL SGTXV( XC, Y(6), 'ABCDEFG abcdefg' )

      CALL SGISET( 'IFONT', 1 )
      CALL SGSTXI( 1 )

*-- ギリシャ文字 ----
      GREEK1 = CSGI(128)//CSGI(129)//CSGI(130)//CSGI(131)//CSGI(132)//
     +         CSGI(133)//CSGI(134)//CSGI(135)//CSGI(136)//CSGI(137)
      GREEK2 = CSGI(152)//CSGI(153)//CSGI(154)//CSGI(155)//CSGI(156)//
     +         CSGI(157)//CSGI(158)//CSGI(159)//CSGI(160)//CSGI(161)

      CALL SGTXV( XC, Y(7), GREEK1 )
      CALL SGTXV( XC, Y(8), GREEK2 )

*-- 特殊記号 ----
      SYMBOL = CSGI(189)//CSGI(190)//CSGI(191)//CSGI(192)//CSGI(193)//
     +         CSGI(210)//CSGI(211)//CSGI(212)//CSGI(217)//CSGI(218)

      CALL SGTXV( XC, Y(9), SYMBOL )

      CALL SGCLS

      END

==> dcl-6.5.3.tar.gz: dcl-6.5.3/demo/rakuraku/kihon/kihonb.f <==
*-----------------------------------------------------------------------
*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
*-----------------------------------------------------------------------
      PROGRAM KIHONB

      PARAMETER( NMAX=9 )
      REAL Y(NMAX)
      CHARACTER GREEK1*10, GREEK2*10, SYMBOL*10, CSGI*1

      WRITE(*,*) ' WORKSTATION ID (I)  ? ;'
      CALL SGPWSN
      READ (*,*) IWS

      CALL SGOPN(IWS)
      CALL SGFRM

      X1 = 0.1
      X2 = 0.9
      XC = 0.5

*-- 罫線 ----
      DO 10 N=1,NMAX
        Y(N) = 0.1*(10-N)
        CALL SGLNV( X1, Y(N), X2, Y(N) )
  10  CONTINUE

      CALL SGLNV( XC, 0.05, XC, 0.95 )

*-- デフォルト ----
      CALL SGTXV( XC, Y(1), 'SGTXV\^{SUP}RST\_{SUB}' )

*-- 添字 ----
      CALL SGLSET( 'LCNTL', .TRUE. )
      CALL SGTXV( XC, Y(2), 'SGTXV\^{SUP}RST\_{SUB}' )

      CALL SGRSET( 'SMALL', 0.5 )
      CALL SGRSET( 'SHIFT', 0.5 )
      CALL SGTXV( XC, Y(3), 'SGTXV\^{SUP}RST\_{SUB}' )

*-- フォント ----
      CALL SGTXV( XC, Y(4), 'ABCDEFG abcdefg' )

      CALL SGISET( 'IFONT', 2 )
      CALL SGTXV( XC, Y(5), 'ABCDEFG abcdefg' )

      CALL SGSTXI( 3 )
      CALL SGTXV( XC, Y(6), 'ABCDEFG abcdefg' )

      CALL SGISET( 'IFONT', 1 )
      CALL SGSTXI( 1 )

*-- ギリシャ文字 ----
      GREEK1 = CSGI(128)//CSGI(129)//CSGI(130)//CSGI(131)//CSGI(132)//
     +         CSGI(133)//CSGI(134)//CSGI(135)//CSGI(136)//CSGI(137)
      GREEK2 = CSGI(152)//CSGI(153)//CSGI(154)//CSGI(155)//CSGI(156)//
     +         CSGI(157)//CSGI(158)//CSGI(159)//CSGI(160)//CSGI(161)

      CALL SGTXV( XC, Y(7), GREEK1 )
      CALL SGTXV( XC, Y(8), GREEK2 )

*-- 特殊記号 ----
      SYMBOL = CSGI(189)//CSGI(190)//CSGI(191)//CSGI(192)//CSGI(193)//
     +         CSGI(210)//CSGI(211)//CSGI(212)//CSGI(217)//CSGI(218)

      CALL SGTXV( XC, Y(9), SYMBOL )

      CALL SGCLS

      END
